<template>
  <div class="equity-registration-warehousing  corporate-customers">
    <div class="left-tree" v-show="componentName === 'table'">
      <tree-side :treeData="treeData" :tabList="tabList" :defaultProps="defaultProps" @currentChange="currentChange"
        @tabChange="tabChange" @filterChange="filterChange"></tree-side>
    </div>
    <div class="right-table " v-show="componentName === 'table'">
      <div class="full-page bg">
        <div class="search-box">
          <SuperSearch :searchForm="queryParams" :basisOption="basisOption" @is-show-advance="advanced()"
            @search="handleSearch" ref="superSearch" />
        </div>
        <div class="main-table-container">
          <div class="table-container" style="padding: 20px">
            <div style="margin-bottom: 10px" ref="btnPanel">
              <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="handleAdd">
                添加
              </el-button>
              <el-button slot="reference" icon="el-icon-delete" type="danger" plain class="btn btn-delete"
                :disabled="this.currentDataDel.length == 0" @click="handleDelete()">
                删除
              </el-button>
            </div>
            <div class="table-content" ref="tabelRef">
              <el-table stripe v-loading="tableLoading" ref="multipleSelection" :data="tableData" :row-key="getRowKey"
                :max-height="tableMaxHeight" class="table-list" border @selection-change="handleSelectionChange"
                @row-dblclick="handleDbClick">
                <el-table-column type="selection" width="55" align="center"></el-table-column>
                <el-table-column type="index" width="60" label="序号" align="center">
                </el-table-column>
                <el-table-column prop="belongsOrgName" show-overflow-tooltip min-width="180" align="center"
                  label="所属公司">
                </el-table-column>
                <el-table-column prop="projectName" show-overflow-tooltip min-width="120" align="center" label="所属项目">
                </el-table-column>
                <el-table-column prop="buildingName" show-overflow-tooltip min-width="120" align="center" label="楼栋名称">
                </el-table-column>
                <el-table-column prop="buildingCode" show-overflow-tooltip min-width="120" align="center" label="楼栋编码">
                </el-table-column>
                <el-table-column prop="buildingNumber" show-overflow-tooltip min-width="120" align="center" label="楼栋号">
                </el-table-column>
                <el-table-column prop="floor" show-overflow-tooltip min-width="120" align="center" label="楼层数">
                </el-table-column>
                <el-table-column prop="floorGround" show-overflow-tooltip min-width="120" align="center" label="地面层数">
                </el-table-column>
                <el-table-column prop="floorUnderground" show-overflow-tooltip min-width="120" align="center"
                  label="地下层数">
                </el-table-column>
                <el-table-column show-overflow-tooltip min-width="120" align="center" fixed="right" label="操作">
                  <template v-slot="{ row }">
                    <el-link type="primary" :underline="false" style="margin-right: 10px;" @click="detailBtn(row)">
                      详情
                    </el-link>
                    <el-link type="danger" :underline="false" style="margin-right: 10px;" @click="handleDelete(row)">
                      删除
                    </el-link>
                  </template>
                </el-table-column>
              </el-table>
              <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParams"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </div>
          </div>
        </div>
      </div>
    </div>

    <!-- 弹层 -->
    <editAddDialog ref="editAddDialog" v-show="componentName === 'editAddDialog'" @closeComponent="closeComponent">
    </editAddDialog>
    <!-- 详情 -->
    <detailDialog v-show="componentName === 'detailDialog'" @closeComponent="closeComponent" ref="detailDialog">
    </detailDialog>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import utils from '@/utils.js'
import detailDialog from './components/detailDialog.vue'
import editAddDialog from './components/editAddDialog.vue'
import SuperSearch from '@/components/SuperSearch/index.vue'
import api from '@/api/assetsOperating/AssetLedgerRegistration/OperatingValuePublic.js'
import treeSide from '@/components/treeSide/index.vue'
import pubSub from 'pubsub-js'

export default {
  name: 'IndividualCustomers',
  components: {
    SuperSearch,
    pagination,
    editAddDialog,
    detailDialog,
    treeSide
  },
  mixins: [TableMixin],
  data() {
    return {
      tableMaxHeight: '600px',
      loading: false,
      tableLoading: false,
      componentName: 'table',
      treeData: [],//左边树
      tabList: ['项目'],//左边tab
      defaultProps: {
        children: 'children',
        label: 'name',
      },
      tableData: [],
      multipleSelection: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'b.belongs_org_id_': null,
        projectName: null,
        projectCode: null,
        projectId: null,
        projectBelong: [],
      },
      searchForm: {}, // 顶部搜索对象
      currentDataDel: [],
      sorter: [
        {
          direction: 'DESC',
          property: 'createTime'
        }
      ],
      basisOption: [
        {
          itemLabel: '楼栋名称',
          itemProp: 'buildingName',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        },
        {
          itemLabel: '楼栋编码',
          itemProp: 'buildingCode',
          itemType: 'input',
          labelWidth: '90px',
          searchType: 'advance'
        },
        // {
        //   itemLabel: '项目',
        //   itemProp: 'projectId',
        //   itemType: 'select',
        //   labelWidth: '90px',
        //   searchType: 'advance',
        //   option: [
        //   ]
        // }

      ],
      pubSub: null

    }
  },

  created() {
    this.getProject()
    this.loadData()
  },
  mounted() {
    this.calcTableHeight()
    this.$root.$on('resize', () => {
      this.calcTableHeight(500)
    })
    // 添加自定义面包屑pub-sub
    this.pubSub = pubSub.subscribe('breadcrumb-click', (_, item) => {
      console.log(item)
      if (item.isCurrentRoute) this.componentName = 'table'
    })
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      /*
       * 定义 escapeOpt 字段对应字典名 对象
       *  为重新加工结构赋值的新请求配置参数
       * */
      const querys = [
        { operation: 'LIKE', property: 'buildingName', relation: 'AND' },
        { operation: 'LIKE', property: 'buildingCode', relation: 'AND' },
        { operation: 'EQUAL', property: 'projectId', relation: 'AND' },
        { operation: 'LIKE', property: 'b.belongs_org_id_', relation: 'AND' },

      ]
      const { pageSize, page, ...item } = this.queryParams
      return {
        pageBean: { pageSize, page },
        querys: querys.flatMap(i => {
          const value = item[i.property]
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return { group: 'main', ...i, value }
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  methods: {
    //关闭组件
    closeComponent(row) {
      this.componentName = 'table'
      this.loadData()

    },
    //字典翻译
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //获取项目下拉
     getProject() {
       api.projectQquery({
        pageBean: {
          pageSize: -1,
          page: 1
        }
      }, res => {
        if (res.rows) {
          this.treeData = res.rows.map(i => {
            return {
              ...i,
              name: i.projectName,
              value: i.id
            }
          })
        }
      })
    },
    //获取数据
    loadData() {
      this.tableLoading = true
      api.queryData(this.computedQuery, res => {
        if (res.rows) {
          this.tableData = res.rows
          this.queryParams.total = res.total
          this.tableLoading = false
        }
      })
    },
    //左边树节点
    currentChange(value, data) {
      this.queryParams.projectId = ''
      if (value) {
          this.queryParams.projectId = value.id
      }
      this.loadData()
    },
    //左边树tab
    tabChange() {
    },
    //左边树搜索
    filterChange(val) {
    },
    //添加
    handleAdd() {
      this.componentName = 'editAddDialog'
      pubSub.publish('add-custom-breadcrumb', '添加')

      this.$refs.editAddDialog.addModifyBtn()
    },
    //详情
    detailBtn(row) {
      this.componentName = 'detailDialog'
      pubSub.publish('add-custom-breadcrumb', '详情')

      this.$refs.detailDialog.detail(row)
    },
    // 删除
    handleDelete(val) {
      let ids
      if (val) {
        ids = val.id
      } else {
        ids = this.currentDataDel.join()
      }
      this.$confirm('确定删除选中数据吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        api.deleteData(ids, res => {
          if (res.state) {
            this.$message.success('删除成功')
            this.loadData()
          }
        })
      })
    },
    //修改
    handleDbClick(row) {
      this.componentName = 'editAddDialog'
      pubSub.publish('add-custom-breadcrumb', '编辑')

      this.$refs.editAddDialog.addModifyBtn(row)
    },
    // 顶部搜索
    handleSearch(data) {
      this.queryParams = data
      this.loadData()
    },
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id;
    },
    //表格选中
    handleSelectionChange(val) {
      this.currentDataDel = val.map((item) => {
        return item.id
      })
    },
    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.loadData()
    },
    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.loadData()
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    pubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped>
/deep/ .full-page {
  padding-left: 16px !important;
}

.equity-registration-warehousing {
  width: 100%;
  display: flex;

  .left-tree {
    margin: 16px 0 0 24px;
  }

  .right-table {
    width: calc(100% - 324px);
  }
}

.search-box {
  //height: 350px;
  padding: 20px 30px;
  transition: all 1s;
  background-color: #ffffff;
  border-radius: 8px;
}

.table-content {
  width: 100%;
  height: calc(100% - 110px);

  .table-list {
    width: 100%;
    height: 100%;
  }
}

/deep/ .el-table .el-table__header th {
  padding: 12px 0 !important;
  background-color: #f1f5f8 !important;
}

/deep/ .el-table .el-table__header th .cell {
  font-size: 16px;
  color: #545454;
  font-weight: 700;
  font-family: PingFang SC-Medium, PingFang SC;
  white-space: nowrap;
}

.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.move-tree /deep/ .el-tree {
  height: 90%;
  overflow-y: auto;
  border: none;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(2) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }

  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}
</style>
